@@ -12,16 +12,22 @@
 
 #define LIBMAMBA_VERSION_MAJOR 0
 #define LIBMAMBA_VERSION_MINOR 18
-#define LIBMAMBA_VERSION_PATCH 1
+#define LIBMAMBA_VERSION_PATCH 2
 
 // Binary version
 #define LIBMAMBA_BINARY_CURRENT 1
 #define LIBMAMBA_BINARY_REVISION 0
 #define LIBMAMBA_BINARY_AGE 0
 
+#define __LIBMAMBA_STRINGIZE_IMPL(s) #s
+#define __LIBMAMBA_STRINGIZE(s) __LIBMAMBA_STRINGIZE_IMPL(s)
+
 #define LIBMAMBA_VERSION                                                                           \
     (LIBMAMBA_VERSION_MAJOR * 10000 + LIBMAMBA_VERSION_MINOR * 100 + LIBMAMBA_VERSION_PATCH)
-#define LIBMAMBA_VERSION_STRING "0.18.1"
+#define LIBMAMBA_VERSION_STRING                                                                    \
+    __LIBMAMBA_STRINGIZE(LIBMAMBA_VERSION_MAJOR)                                                   \
+    "." __LIBMAMBA_STRINGIZE(LIBMAMBA_VERSION_MINOR) "." __LIBMAMBA_STRINGIZE(                     \
+        LIBMAMBA_VERSION_PATCH)
 
 namespace mamba
 {
